#! /usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chalk from 'chalk';
import { BuildTask, getArgvNoBin, initAsync, logReply } from '../modules/common.js';
import { info, warn } from '../modules/consolePlus.js';
import { askToConfirm, buildApk, getBuildTask, getNewVersionCode, getNewVersionName } from '../modules/helper.js';
import { getAppJSonVersion, getBuildGradleVersion, getConfig, getPackageVersion } from '../modules/reader.js';
import { updateVersions } from '../modules/writer.js';
import yargs from 'yargs';
var OutputFlag;
(function (OutputFlag) {
    OutputFlag["Debug"] = "d";
    OutputFlag["ReleaseApk"] = "r-apk";
    OutputFlag["ReleaseAab"] = "r-aab";
    OutputFlag["ReleaseFull"] = "r-full";
})(OutputFlag || (OutputFlag = {}));
const getOutputChoices = () => Object.values(OutputFlag).filter((val) => val.toLowerCase() === val);
const parser = yargs(getArgvNoBin()).options({
    output: {
        alias: 'o',
        choices: getOutputChoices(),
        desc: 'Choose output type',
    },
    ['same-version']: {
        type: 'boolean',
        desc: 'Do not increment the version',
        default: false,
    },
    verbose: {
        type: 'boolean',
        desc: 'Returns more information on errors etc',
        default: false,
    },
});
const { red, cyan, yellow } = chalk;
process.on('uncaughtException', (err) => __awaiter(void 0, void 0, void 0, function* () {
    const args = yield parser.argv;
    if (args === null || args === void 0 ? void 0 : args.verbose) {
        console.error(err);
    }
    console.log(`${red.bold('!')} Aborted!\n`);
    process.exit();
}));
const getTask = (output) => __awaiter(void 0, void 0, void 0, function* () {
    if (!output)
        return yield getBuildTask();
    switch (output) {
        case OutputFlag.Debug:
            return BuildTask.Debug;
        case OutputFlag.ReleaseApk:
            return BuildTask.ReleaseApk;
        case OutputFlag.ReleaseAab:
            return BuildTask.ReleaseBundle;
        case OutputFlag.ReleaseFull:
            return BuildTask.ReleaseFull;
        default:
            console.warn('Unexpected error parsing output. Continuing as debug apk...');
            return BuildTask.Debug;
    }
});
const getVersion = (verName, verCode, sameVersion) => __awaiter(void 0, void 0, void 0, function* () {
    if (sameVersion) {
        return {
            versionName: verName,
            versionCode: verCode,
        };
    }
    else {
        const newVersionName = yield getNewVersionName(verName);
        const newVersionCode = getNewVersionCode(verCode);
        return {
            versionName: newVersionName,
            versionCode: newVersionCode,
        };
    }
});
/**
 * Starts the main process of the **_manage-build_** CLI command.
 */
export const startManageBuildAsync = () => __awaiter(void 0, void 0, void 0, function* () {
    const args = yield parser.argv;
    const config = getConfig();
    const appJsonVer = config.expo ? getAppJSonVersion() : '';
    const { versionName: currentVerName, versionCode: currentVerCode } = getBuildGradleVersion();
    const packageVersionName = getPackageVersion();
    const matchingVersions = config.expo ? appJsonVer === currentVerName && currentVerName === packageVersionName : currentVerName === packageVersionName;
    if (!matchingVersions) {
        warn('Mismatched versions. Using the version in build.gradle...');
    }
    const { versionName: newVersionName, versionCode: newVersionCode } = yield getVersion(currentVerName, currentVerCode, args['same-version']);
    info(`Version Name: ${yellow(currentVerName)} => ${cyan(newVersionName)}`);
    info(`Version Code: ${yellow(currentVerCode)} => ${cyan(newVersionCode)}\n`);
    const task = yield getTask(args === null || args === void 0 ? void 0 : args.output);
    logReply(task);
    console.log();
    const confirmed = askToConfirm();
    // time to actually build the new version
    if (confirmed) {
        // Time to change the versions in the files
        updateVersions(newVersionName, newVersionCode, config.expo);
        buildApk(task);
    }
    else {
        console.log('Aborting...\n');
    }
});
initAsync(true);
//# sourceMappingURL=manage-build.js.map